@@ -3,6 +3,7 @@ use std::{
     borrow::ToOwned,
     fmt, io,
     process::{ExitCode, Termination},
+    sync::OnceLock,
 };
 
 macro_rules! wout {
@@ -81,6 +82,8 @@ macro_rules! fail_format {
     }};
 }
 
+pub static CURRENT_COMMAND: OnceLock<String> = OnceLock::new();
+
 #[repr(u8)]
 pub enum QsvExitCode {
     Good           = 0,
@@ -166,9 +169,8 @@ impl From<serde_json::Error> for CliError {
     }
 }
 
-#[cfg(all(target_os = "linux", feature = "magic"))]
-impl From<magic::MagicError> for CliError {
-    fn from(err: magic::MagicError) -> CliError {
-        CliError::Other(format!("magic error: {err:?}"))
+impl From<reqwest::Error> for CliError {
+    fn from(err: reqwest::Error) -> CliError {
+        CliError::Other(err.to_string())
     }
 }
