@@ -32,8 +32,7 @@ Excel options:
                                
                                All other Excel options are ignored.
                                [default: none]
-    --flexible                 Continue even if the number of columns is different 
-                               from the previous record.
+    --flexible                 Continue even if the number of columns is different from row to row.
     --trim                     Trim all fields so that leading & trailing whitespaces are removed.
                                Also removes embedded linebreaks.
     --date-format <format>     Optional date format to use when formatting dates.
@@ -46,6 +45,8 @@ Excel options:
 Common options:
     -h, --help                 Display this message
     -o, --output <file>        Write output to <file> instead of stdout.
+    -d, --delimiter <arg>      The delimiter to use when writing CSV data.
+                               Must be a single character. [default: ,]
     -Q, --quiet                Do not display export summary message.
 "#;
 
@@ -56,7 +57,10 @@ use log::info;
 use serde::{Deserialize, Serialize};
 use thousands::Separable;
 
-use crate::{config::Config, util, CliResult};
+use crate::{
+    config::{Config, Delimiter},
+    util, CliResult,
+};
 
 #[derive(Deserialize)]
 struct Args {
@@ -66,6 +70,7 @@ struct Args {
     flag_flexible:    bool,
     flag_trim:        bool,
     flag_output:      Option<String>,
+    flag_delimiter:   Option<Delimiter>,
     flag_quiet:       bool,
     flag_date_format: Option<String>,
     flag_range:       String,
@@ -178,7 +183,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 "\"{format}\" not supported. The excel command only supports the following file \
                  formats - xls, xlsx, xlsm, xlsb and ods."
             );
-        }
+        },
     };
 
     let requested_range = args.flag_range.to_lowercase();
@@ -194,7 +199,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 return fail_clierror!("{path} may be a password-protected workbook: {e}.");
             }
             return fail_clierror!("Cannot open workbook: {e}.");
-        }
+        },
     };
 
     let sheet_names = workbook.sheet_names();
@@ -209,6 +214,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     let mut wtr = Config::new(&args.flag_output)
         .flexible(args.flag_flexible)
+        .delimiter(args.flag_delimiter)
         .writer()?;
 
     // set Metadata Mode
@@ -220,7 +226,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         'n' | 'N' => MetadataMode::None,
         _ => {
             return fail_clierror!("Invalid mode: {}", args.flag_metadata);
-        }
+        },
     };
 
     if metadata_mode != MetadataMode::None {
@@ -239,7 +245,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     Ok(result) => result,
                     Err(e) => {
                         return fail_clierror!("Cannot retrieve range from {sheet_name}: {e}.");
-                    }
+                    },
                 }
             } else {
                 Range::empty()
@@ -344,20 +350,20 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     wtr.write_record(&metadata_record)?;
                 }
                 wtr.flush()?;
-            }
+            },
             MetadataMode::Json => {
                 let Ok(json_result) = serde_json::to_string(&excelmetadata_struct) else {
                     return fail!("Cannot create JSON");
                 };
                 println!("{json_result}");
-            }
+            },
             MetadataMode::PrettyJSON => {
                 let Ok(json_result) = serde_json::to_string_pretty(&excelmetadata_struct) else {
                     return fail!("Cannot create pretty JSON");
                 };
                 println!("{json_result}");
-            }
-            MetadataMode::None => {}
+            },
+            MetadataMode::None => {},
         }
         info!(r#"exported metadata for "{path}" workbook sheets: {sheet_vec:?}"#);
         // after we export metadata, we're done.
@@ -447,135 +453,39 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     let (row_count, col_count) = range.get_size();
 
-    // use with_capacity to minimize reallocations
-    let mut record = csv::StringRecord::with_capacity(500, col_count);
-    let mut trimmed_record = csv::StringRecord::with_capacity(500, col_count);
+    if row_count > 0 {
+        let mut rows_iter = range.rows();
 
-    let mut cell_date_flag: bool = false;
-    let mut float_val = 0_f64;
-    let mut float_flag: bool = false;
+        // use with_capacity to minimize reallocations
+        let mut record = csv::StringRecord::with_capacity(500, col_count);
+        let mut trimmed_record = csv::StringRecord::with_capacity(500, col_count);
 
-    let date_format = if let Some(df) = args.flag_date_format {
-        df
-    } else {
-        String::new()
-    };
-    let mut work_date;
+        let mut col_name: String;
 
-    info!("exporting sheet ({sheet})...");
-    for (row_idx, row) in range.rows().enumerate() {
-        record.clear();
-        for cell in row {
-            if row_idx == 0 {
-                // its the header row, check the dates whitelist
-                info!("processing first row...");
-                let col_name: String = match *cell {
-                    DataType::Empty => String::new(),
-                    DataType::Error(ref _e) => String::new(),
-                    DataType::String(ref s) => s.to_string(),
-                    DataType::Int(ref i) => i.to_string(),
-                    DataType::DateTime(ref f) | DataType::Float(ref f) => f.to_string(),
-                    DataType::Bool(ref b) => b.to_string(),
-                    DataType::DateTimeIso(ref dt) => dt.to_string(),
-                    DataType::DurationIso(ref d) => d.to_string(),
-                    DataType::Duration(ref d) => d.to_string(),
-                };
-                record.push_field(&col_name);
-                continue;
-            }
-            match *cell {
-                DataType::Empty => record.push_field(""),
-                DataType::String(ref s) => record.push_field(s),
-                DataType::Int(ref i) => {
-                    let mut buffer = itoa::Buffer::new();
-                    record.push_field(buffer.format(*i));
-                }
-                DataType::DateTime(ref f) => {
-                    float_val = *f;
-                    float_flag = true;
-                    cell_date_flag = true;
-                }
-                DataType::Float(ref f) => {
-                    float_val = *f;
-                    float_flag = true;
-                    cell_date_flag = false;
-                }
-                DataType::Error(ref e) => record.push_field(&format!("{e:?}")),
-                DataType::Bool(ref b) => record.push_field(&b.to_string()),
-                DataType::DateTimeIso(ref dt) => record.push_field(&dt.to_string()),
-                DataType::DurationIso(ref d) => record.push_field(&d.to_string()),
-                DataType::Duration(ref d) => {
-                    let mut buffer = ryu::Buffer::new();
-                    record.push_field(buffer.format(*d));
-                }
+        info!("exporting sheet ({sheet})... processing first row as header...");
+        let first_row = match rows_iter.next() {
+            Some(first_row) => first_row,
+            None => &[DataType::Empty],
+        };
+        for cell in first_row {
+            col_name = match *cell {
+                DataType::String(ref s) => s.to_string(),
+                DataType::Empty => String::new(),
+                DataType::Error(ref _e) => String::new(),
+                DataType::Int(ref i) => i.to_string(),
+                DataType::DateTime(ref f) | DataType::Float(ref f) => f.to_string(),
+                DataType::Bool(ref b) => b.to_string(),
+                DataType::DateTimeIso(ref dt) => dt.to_string(),
+                DataType::DurationIso(ref d) => d.to_string(),
+                DataType::Duration(ref d) => d.to_string(),
             };
-
-            // Dates are stored as floats in Excel's older binary format (XLS - Excel 97-2003.)
-            // That's why we need the --dates-whitelist, so we can convert the float to a date.
-            // However, with the more recent XLSX format (Excel 2007 & later), we can get a cell's
-            // format as a cell attribute. So we can automatically process a cell as a date,
-            // even if its column is NOT in the whitelist
-            #[allow(clippy::cast_precision_loss)]
-            if float_flag {
-                if cell_date_flag {
-                    // its a date, so convert it
-                    work_date = if float_val.fract() > 0.0 {
-                        // if it has a fractional part, then its a datetime
-                        if let Some(dt) = cell.as_datetime() {
-                            if date_format.is_empty() {
-                                // no date format specified, so we'll just use the default
-                                // format for the datetime
-                                dt.to_string()
-                            } else {
-                                // a date format was specified, so we'll use it
-                                let mut formatted = String::new();
-                                if write!(formatted, "{}", dt.format(&date_format)).is_err() {
-                                    // if there was a format error, revert to the default format
-                                    formatted = dt.to_string();
-                                }
-                                formatted
-                            }
-                        } else {
-                            format!("ERROR: Cannot convert {float_val} to datetime")
-                        }
-                    } else if let Some(d) = cell.as_date() {
-                        // if it has no fractional part and calamine can return it as_date
-                        // then its a date
-                        if date_format.is_empty() {
-                            d.to_string()
-                        } else {
-                            let mut formatted = String::new();
-                            if write!(formatted, "{}", d.format(&date_format)).is_err() {
-                                formatted = d.to_string();
-                            }
-                            formatted
-                        }
-                    } else {
-                        format!("ERROR: Cannot convert {float_val} to date")
-                    };
-                    record.push_field(&work_date);
-                // its not a date, so just push the ryu-formatted float value if its not an integer
-                // or the candidate integer is too big or too small to be an i64
-                } else if float_val.fract().abs() > 0.0
-                    || float_val > i64::MAX as f64
-                    || float_val < i64::MIN as f64
-                {
-                    let mut buffer = ryu::Buffer::new();
-                    record.push_field(buffer.format_finite(float_val));
-                } else {
-                    // its an i64 integer. We can't use ryu to format it, because it will
-                    // be formatted as a float (have a ".0"). So we use itoa.
-                    let mut buffer = itoa::Buffer::new();
-                    record.push_field(buffer.format(float_val as i64));
-                }
-                // set the float flag to false, so we don't try to process the next cell as a float
-                float_flag = false;
-            }
+            record.push_field(&col_name);
         }
 
-        if args.flag_trim {
+        let trim = args.flag_trim;
+
+        if trim {
             record.trim();
-            trimmed_record.clear();
             record.iter().for_each(|field| {
                 if field.contains('\n') {
                     trimmed_record.push_field(&field.to_string().replace('\n', " "));
@@ -587,7 +497,134 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         } else {
             wtr.write_record(&record)?;
         }
+
+        // process the rest of the rows
+        // first, amortize allocs by declaring mutable vars we'll use
+        // in the main processing loop here
+        let mut cell_date_flag: bool = false;
+        let mut float_val = 0_f64;
+        let mut float_flag: bool = false;
+
+        let date_format = if let Some(df) = args.flag_date_format {
+            df
+        } else {
+            String::new()
+        };
+        let mut work_date;
+        let mut ryu_buffer = ryu::Buffer::new();
+        let mut itoa_buffer = itoa::Buffer::new();
+        let mut formatted_date = String::new();
+
+        // main processing loop
+        for row in rows_iter {
+            record.clear();
+            for cell in row {
+                match *cell {
+                    DataType::Empty => record.push_field(""),
+                    DataType::String(ref s) => record.push_field(s),
+                    DataType::Int(ref i) => {
+                        let mut buffer = itoa::Buffer::new();
+                        record.push_field(buffer.format(*i));
+                    },
+                    DataType::Float(ref f) => {
+                        float_val = *f;
+                        float_flag = true;
+                        cell_date_flag = false;
+                    },
+                    DataType::DateTime(ref f) => {
+                        float_val = *f;
+                        float_flag = true;
+                        cell_date_flag = true;
+                    },
+                    DataType::Error(ref e) => record.push_field(&format!("{e:?}")),
+                    DataType::Bool(ref b) => record.push_field(&b.to_string()),
+                    DataType::DateTimeIso(ref dt) => record.push_field(&dt.to_string()),
+                    DataType::DurationIso(ref d) => record.push_field(&d.to_string()),
+                    DataType::Duration(ref d) => record.push_field(ryu_buffer.format(*d)),
+                };
+
+                // Dates are stored as floats in Excel, so if its a float value, we need to check
+                // if its a date. If its a date, we need to convert it to a string using the
+                // specified date format. If its not a date, we need to convert it to a string
+                // using ryu.
+                #[allow(clippy::cast_precision_loss)]
+                if float_flag {
+                    if cell_date_flag {
+                        // its a date, so convert it
+                        work_date = if float_val.fract() > 0.0 {
+                            // if it has a fractional part, then its a datetime
+                            if let Some(dt) = cell.as_datetime() {
+                                if date_format.is_empty() {
+                                    // no date format specified, so we'll just use the default
+                                    // format for the datetime
+                                    dt.to_string()
+                                } else {
+                                    // a date format was specified, so we'll use it
+                                    (formatted_date).clear();
+                                    if write!(formatted_date, "{}", dt.format(&date_format)).is_ok()
+                                    {
+                                        // the format string was ok, so use to_string() to
+                                        // actually apply the DelayedFormat
+                                        formatted_date.to_string()
+                                    } else {
+                                        // if there was a format error, revert to the default format
+                                        dt.to_string()
+                                    }
+                                }
+                            } else {
+                                format!("ERROR: Cannot convert {float_val} to datetime")
+                            }
+                        } else if let Some(d) = cell.as_date() {
+                            // if it has no fractional part and calamine can return it as_date
+                            // then its a date
+                            if date_format.is_empty() {
+                                d.to_string()
+                            } else {
+                                formatted_date.clear();
+                                if write!(formatted_date, "{}", d.format(&date_format)).is_ok() {
+                                    formatted_date.to_string()
+                                } else {
+                                    d.to_string()
+                                }
+                            }
+                        } else {
+                            format!("ERROR: Cannot convert {float_val} to date")
+                        };
+                        record.push_field(&work_date);
+                    // its not a date, so just push the ryu-formatted float value if its not an
+                    // integer or the candidate integer is too big or too small to be an i64
+                    } else if float_val.fract().abs() > 0.0
+                        || float_val > i64::MAX as f64
+                        || float_val < i64::MIN as f64
+                    {
+                        record.push_field(ryu_buffer.format_finite(float_val));
+                    } else {
+                        // its an i64 integer. We can't use ryu to format it, because it will
+                        // be formatted as a float (have a ".0"). So we use itoa.
+                        record.push_field(itoa_buffer.format(float_val as i64));
+                    }
+                    // reset the float flag
+                    float_flag = false;
+                }
+            }
+
+            if trim {
+                record.trim();
+                trimmed_record.clear();
+                record.iter().for_each(|field| {
+                    if field.contains('\n') {
+                        trimmed_record.push_field(&field.to_string().replace('\n', " "));
+                    } else {
+                        trimmed_record.push_field(field);
+                    }
+                });
+                wtr.write_record(&trimmed_record)?;
+            } else {
+                wtr.write_record(&record)?;
+            }
+        }
     }
+
     wtr.flush()?;
 
     if !args.flag_quiet {
