@@ -270,7 +270,7 @@ impl Filler {
                 .or_insert_with(|| GroupValues::new(default_value));
 
             match (self.default_value.is_some(), self.first) {
-                (true, _) => {}
+                (true, _) => {},
                 (false, true) => group.memorize_first(&self.select, &record),
                 (false, false) => group.memorize(&self.select, &record),
             };
@@ -279,10 +279,7 @@ impl Filler {
 
             // Handle buffering rows which still have nulls.
             if self.backfill && (self.select.iter().any(|&i| row[i] == b"")) {
-                self.buffer
-                    .entry(key.clone())
-                    .or_insert_with(Vec::new)
-                    .push(row);
+                self.buffer.entry(key.clone()).or_default().push(row);
             } else {
                 if let Some(rows) = self.buffer.remove(&key) {
                     for buffered_row in rows {
@@ -328,7 +325,7 @@ where
             ref mut sidx if (self.selection.get(*sidx) == Some(&self.index)) => {
                 *sidx += 1;
                 Some((self.predicate)(item))
-            }
+            },
             _ => Some(item),
         };
         self.index += 1;
