@@ -1,7 +1,7 @@
 #![cfg(target_family = "unix")]
 static USAGE: &str = r#"
 Execute a shell command once per line in given CSV file. Only works in
-Linux, macOS and other Unix-like environments.
+Linux, macOS and other Unix-like environments (i.e. not Windows).
 
 Deleting all files whose filenames are listed in a column:
 
@@ -21,6 +21,15 @@ Usage:
     qsv foreach [options] <column> <command> [<input>]
     qsv foreach --help
 
+foreach arguments:
+    column                The column to use as input for the command.
+    command               The command to execute. Use "{}" to substitute the value
+                          of the current input file line.
+                          If you need to execute multiple commands, use a shell
+                          script. See foreach_multiple_commands_with_shell_script()
+                          in tests/test_foreach.rs for an example.
+    input                 The CSV file to read. If not provided, will read from stdin.
+
 foreach options:
     -u, --unify              If the output of execute command is CSV, will
                              unify the result by skipping headers on each
@@ -77,8 +86,18 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut wtr = Config::new(&None).writer()?;
 
     #[allow(clippy::trivial_regex)]
+    // template_pattern matches pairs of curly braces, e.g. "{}".
     let template_pattern = Regex::new(r"\{\}")?;
-    let splitter_pattern = Regex::new(r#"(?:[\w-]+|"[^"]*"|'[^']*'|`[^`]*`)"#)?;
+
+    // splitter_pattern gets all the arguments to the command as tokens.
+    // The regular expression matches any sequence of characters that consists of one or more word
+    // characters (`a-z`, `A-Z`, `0-9`, `_`, `.`, `+`, `-`), or any of the following three types of
+    // quoted strings: double-quoted strings ("..."), single-quoted strings ('...'), or
+    // backtick-quoted strings (`...`).
+    let splitter_pattern = Regex::new(r#"(?:[a-zA-Z0-9_.+-]+|"[^"]*"|'[^']*'|`[^`]*`)"#)?;
+
+    // cleaner_pattern removes the quotes or backticks from the quoted strings matched by
+    // splitter_pattern.
     let cleaner_pattern = Regex::new(r#"(?:^["'`]|["'`]$)"#)?;
 
     let headers = rdr.byte_headers()?.clone();
@@ -133,7 +152,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             {
                 let stdout = cmd.stdout.as_mut().unwrap();
                 let stdout_reader = BufReader::new(stdout);
-                // let stdout_lines = stdout_reader.lines();
 
                 let mut stdout_rdr = csv::ReaderBuilder::new()
                     .delimiter(match &args.flag_delimiter {
@@ -165,16 +183,15 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 }
             }
 
-            cmd.wait().unwrap();
+            cmd.wait()?;
         } else {
             let mut cmd = Command::new(prog)
                 .args(cmd_args)
                 .stdout(Stdio::inherit())
                 .stderr(Stdio::inherit())
-                .spawn()
-                .unwrap();
+                .spawn()?;
 
-            cmd.wait().unwrap();
+            cmd.wait()?;
         }
     }
     if show_progress {
