@@ -94,17 +94,21 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         _ => args.sequential_ftables(),
     }?;
 
+    #[allow(unused_assignments)]
+    let mut header_vec: Vec<u8> = Vec::with_capacity(tables.len());
+    let mut buffer = itoa::Buffer::new();
+    let mut row;
+
     wtr.write_record(vec!["field", "value", "count"])?;
     let head_ftables = headers.iter().zip(tables);
     for (i, (header, ftab)) in head_ftables.enumerate() {
-        let header = if rconfig.no_headers {
+        header_vec = if rconfig.no_headers {
             (i + 1).to_string().into_bytes()
         } else {
             header.to_vec()
         };
         for (value, count) in args.counts(&ftab) {
-            let count = count.to_string();
-            let row = vec![&*header, &*value, count.as_bytes()];
+            row = vec![&*header_vec, &*value, buffer.format(count).as_bytes()];
             wtr.write_record(row)?;
         }
     }
@@ -152,7 +156,7 @@ impl Args {
 
     pub fn parallel_ftables(
         &self,
-        idx: &mut Indexed<fs::File, fs::File>,
+        idx: &Indexed<fs::File, fs::File>,
     ) -> CliResult<(Headers, FTables)> {
         let mut rdr = self.rconfig().reader()?;
         let (headers, sel) = self.sel_headers(&mut rdr)?;
@@ -179,6 +183,7 @@ impl Args {
         Ok((headers, merge_all(recv.iter()).unwrap()))
     }
 
+    #[inline]
     fn ftables<I>(&self, sel: &Selection, it: I) -> CliResult<FTables>
     where
         I: Iterator<Item = csv::Result<csv::ByteRecord>>,
@@ -189,19 +194,21 @@ impl Args {
         #[allow(unused_assignments)]
         // amortize allocation
         let mut field_work: Vec<u8> = Vec::with_capacity(100);
-        let mut row_work: csv::ByteRecord;
+        let mut row_work: csv::ByteRecord = csv::ByteRecord::default();
+        let flag_no_nulls = self.flag_no_nulls;
         for row in it {
-            row_work = row?;
+            row_work.clone_from(&row?);
             for (i, field) in nsel.select(row_work.into_iter()).enumerate() {
                 field_work = {
-                    match simdutf8::basic::from_utf8(field) {
-                        Ok(s) => s.trim().as_bytes().to_vec(),
-                        Err(_) => field.to_vec(),
+                    if let Ok(s) = simdutf8::basic::from_utf8(field) {
+                        s.trim().as_bytes().to_vec()
+                    } else {
+                        field.to_vec()
                     }
                 };
                 if !field_work.is_empty() {
                     tabs[i].add(field_work);
-                } else if !self.flag_no_nulls {
+                } else if !flag_no_nulls {
                     tabs[i].add(null.clone());
                 }
             }
