@@ -115,31 +115,31 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         (true, false, false, false, false, false) => {
             state.write_headers()?;
             state.outer_join(false)
-        }
+        },
         (false, true, false, false, false, false) => {
             state.write_headers1()?;
             state.left_join(true)
-        }
+        },
         (false, false, true, false, false, false) => {
             state.write_headers1()?;
             state.left_join(false)
-        }
+        },
         (false, false, false, true, false, false) => {
             state.write_headers()?;
             state.outer_join(true)
-        }
+        },
         (false, false, false, false, true, false) => {
             state.write_headers()?;
             state.full_outer_join()
-        }
+        },
         (false, false, false, false, false, true) => {
             state.write_headers()?;
             state.cross_join()
-        }
+        },
         (false, false, false, false, false, false) => {
             state.write_headers()?;
             state.inner_join()
-        }
+        },
         _ => fail!("Please pick exactly one join operation."),
     }
 }
@@ -176,9 +176,10 @@ impl<R: io::Read + io::Seek, W: io::Write> IoState<R, W> {
     fn inner_join(mut self) -> CliResult<()> {
         let mut scratch = csv::ByteRecord::new();
         let mut validx = ValueIndex::new(self.rdr2, &self.sel2, self.casei, self.nulls)?;
-        for row in self.rdr1.byte_records() {
-            let row = row?;
-            let key = get_row_key(&self.sel1, &row, self.casei);
+        let mut row = csv::ByteRecord::new();
+        let mut key;
+        while self.rdr1.read_byte_record(&mut row)? {
+            key = get_row_key(&self.sel1, &row, self.casei);
             if let Some(rows) = validx.values.get(&key) {
                 for &rowi in rows {
                     validx.idx.seek(rowi as u64)?;
@@ -201,9 +202,10 @@ impl<R: io::Read + io::Seek, W: io::Write> IoState<R, W> {
         let mut scratch = csv::ByteRecord::new();
         let (_, pad2) = self.get_padding()?;
         let mut validx = ValueIndex::new(self.rdr2, &self.sel2, self.casei, self.nulls)?;
-        for row in self.rdr1.byte_records() {
-            let row = row?;
-            let key = get_row_key(&self.sel1, &row, self.casei);
+        let mut row = csv::ByteRecord::new();
+        let mut key;
+        while self.rdr1.read_byte_record(&mut row)? {
+            key = get_row_key(&self.sel1, &row, self.casei);
             if let Some(rows) = validx.values.get(&key) {
                 for &rowi in rows {
                     validx.idx.seek(rowi as u64)?;
@@ -226,23 +228,16 @@ impl<R: io::Read + io::Seek, W: io::Write> IoState<R, W> {
 
     fn left_join(mut self, anti: bool) -> CliResult<()> {
         let validx = ValueIndex::new(self.rdr2, &self.sel2, self.casei, self.nulls)?;
-        let mut first_row: bool = true;
-        for row in self.rdr1.byte_records() {
-            let row = row?;
-            let key = get_row_key(&self.sel1, &row, self.casei);
+        let mut row = csv::ByteRecord::new();
+        let mut key;
+        while self.rdr1.read_byte_record(&mut row)? {
+            key = get_row_key(&self.sel1, &row, self.casei);
             if validx.values.get(&key).is_none() {
                 if anti {
                     self.wtr.write_record(&row)?;
                 }
             } else if !anti {
-                // semi_join
-                if first_row {
-                    first_row = false;
-                } else {
-                    // since the first row in a left-semi is
-                    // the header, even if no-header is on
-                    self.wtr.write_record(&row)?;
-                }
+                self.wtr.write_record(&row)?;
             }
         }
         Ok(())
@@ -255,9 +250,10 @@ impl<R: io::Read + io::Seek, W: io::Write> IoState<R, W> {
 
         // Keep track of which rows we've written from rdr2.
         let mut rdr2_written: Vec<_> = repeat(false).take(validx.num_rows).collect();
-        for row1 in self.rdr1.byte_records() {
-            let row1 = row1?;
-            let key = get_row_key(&self.sel1, &row1, self.casei);
+        let mut row1 = csv::ByteRecord::new();
+        let mut key;
+        while self.rdr1.read_byte_record(&mut row1)? {
+            key = get_row_key(&self.sel1, &row1, self.casei);
             if let Some(rows) = validx.values.get(&key) {
                 for &rowi in rows {
                     rdr2_written[rowi] = true;
@@ -287,10 +283,11 @@ impl<R: io::Read + io::Seek, W: io::Write> IoState<R, W> {
         let mut pos = csv::Position::new();
         pos.set_byte(0);
         let mut row2 = csv::ByteRecord::new();
-        for row1 in self.rdr1.byte_records() {
-            let row1 = row1?;
+        let mut row1 = csv::ByteRecord::new();
+        let rdr2_has_headers = self.rdr2.has_headers();
+        while self.rdr1.read_byte_record(&mut row1)? {
             self.rdr2.seek(pos.clone())?;
-            if self.rdr2.has_headers() {
+            if rdr2_has_headers {
                 // Read and skip the header row, since CSV readers disable
                 // the header skipping logic after being seeked.
                 self.rdr2.read_byte_record(&mut row2)?;
@@ -416,10 +413,10 @@ impl<R: io::Read + io::Seek> ValueIndex<R> {
                         let mut rows = Vec::with_capacity(4);
                         rows.push(rowi);
                         v.insert(rows);
-                    }
+                    },
                     Entry::Occupied(mut v) => {
                         v.get_mut().push(rowi);
-                    }
+                    },
                 }
             }
             rowi += 1;
