@@ -171,6 +171,7 @@ Luau options:
                              can "require" lua/luau library files from.
                              See https://www.lua.org/pil/8.1.html
                              [default: ?;?.luau;?.lua]
+    --no-jit                 Don't use luau's JIT compiler.
     --max-errors <count>     The maximum number of errors to tolerate before aborting.
                              Set to zero to disable error limit.
                              [default: 100]
@@ -242,6 +243,7 @@ struct Args {
     flag_begin:       Option<String>,
     flag_end:         Option<String>,
     flag_luau_path:   String,
+    flag_no_jit:      bool,
     flag_output:      Option<String>,
     flag_no_headers:  bool,
     flag_delimiter:   Option<Delimiter>,
@@ -429,11 +431,12 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     debug!("END script: {end_script:?}");
 
     // check if "require" was used in the scripts. If so, we need to setup LUAU_PATH;
-    // we check for "require \"" so we don't trigger on just the literal "require"
-    // which is a fairly common word (e.g. requirements, required, requires, etc.)
-    let require_used = main_script.contains("require \"")
-        || begin_script.contains("require \"")
-        || end_script.contains("require \"");
+    // we check for '= require "' using a robust regex pattern.
+    // \u0022 is the unicode codepoint for a double quote.
+    let requires_re = regex::Regex::new(r"(?mi)=[[:blank:]]*require[[:blank:]]+\u0022").unwrap();
+    let require_used = requires_re.is_match(&main_script)
+        || requires_re.is_match(&begin_script)
+        || requires_re.is_match(&end_script);
 
     // if require_used, create a temporary directory and copy date.lua there.
     // we do this outside the "require_used" setup below as the tempdir
@@ -443,12 +446,12 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             Ok(temp_dir) => {
                 let temp_dir_path = temp_dir.into_path();
                 Some(temp_dir_path)
-            }
+            },
             Err(e) => {
                 return fail_clierror!(
                     "Cannot create temporary directory to copy luadate library to: {e}"
                 )
-            }
+            },
         }
     } else {
         None
@@ -490,6 +493,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     // set default Luau compiler
     luau.set_compiler(luau_compiler.clone());
 
+    luau.enable_jit(!args.flag_no_jit);
+
     let globals = luau.globals();
 
     // check the QSV_CKAN_API environment variable
@@ -720,7 +725,7 @@ fn sequential_mode(
 
                 mlua::IntoLua::into_lua(err_msg, luau)
                     .map_err(|e| format!("Failed to convert error message to Lua: {e}"))?
-            }
+            },
         };
 
         if QSV_BREAK.load(Ordering::Relaxed) {
@@ -814,7 +819,7 @@ fn sequential_mode(
 
                 mlua::IntoLua::into_lua(err_msg, luau)
                     .map_err(|e| format!("Failed to convert error message to Lua: {e}"))?
-            }
+            },
         };
 
         // check if qsv_insertrecord() was called in the END script
@@ -830,7 +835,7 @@ fn sequential_mode(
                 return fail_clierror!(
                     "Unexpected END value type returned by provided Luau expression. {end_value:?}"
                 );
-            }
+            },
         };
         if !end_string.is_empty() && !show_progress {
             winfo!("{end_string}");
@@ -1057,7 +1062,7 @@ fn random_access_mode(
 
                 mlua::IntoLua::into_lua(err_msg, luau)
                     .map_err(|e| format!("Failed to convert error message to Lua: {e}"))?
-            }
+            },
         };
 
         if QSV_BREAK.load(Ordering::Relaxed) {
@@ -1154,7 +1159,7 @@ fn random_access_mode(
 
                 mlua::IntoLua::into_lua(err_msg, luau)
                     .map_err(|e| format!("Failed to convert error message to Lua: {e}"))?
-            }
+            },
         };
 
         // check if qsv_insertrecord() was called in the END script
@@ -1170,7 +1175,7 @@ fn random_access_mode(
                 return fail_clierror!(
                     "Unexpected END value type returned by provided Luau expression. {end_value:?}"
                 );
-            }
+            },
         };
         if !end_string.is_empty() && !show_progress {
             winfo!("{end_string}");
@@ -1205,21 +1210,21 @@ fn map_computedvalue(
     match computed_value {
         Value::String(string) => {
             record.push_field(&string.to_string_lossy());
-        }
+        },
         Value::Number(number) => {
             let mut buffer = ryu::Buffer::new();
             record.push_field(buffer.format(number));
-        }
+        },
         Value::Integer(number) => {
             let mut buffer = itoa::Buffer::new();
             record.push_field(buffer.format(number));
-        }
+        },
         Value::Boolean(boolean) => {
             record.push_field(if boolean { "true" } else { "false" });
-        }
+        },
         Value::Nil => {
             record.push_field("");
-        }
+        },
         Value::Table(table) => {
             if args.flag_remap {
                 // we're in remap mode, so we clear the record
@@ -1234,25 +1239,25 @@ fn map_computedvalue(
                     Value::Integer(intval) => {
                         let mut buffer = itoa::Buffer::new();
                         record.push_field(buffer.format(intval));
-                    }
+                    },
                     Value::String(strval) => {
                         record.push_field(&strval.to_string_lossy());
-                    }
+                    },
                     Value::Number(number) => {
                         let mut buffer = ryu::Buffer::new();
                         record.push_field(buffer.format(number));
-                    }
+                    },
                     Value::Boolean(boolean) => {
                         record.push_field(if boolean { "true" } else { "false" });
-                    }
+                    },
                     Value::Nil => {
                         record.push_field("");
-                    }
+                    },
                     _ => {
                         return fail_clierror!(
                             "Unexpected value type returned by provided Luau expression. {v:?}"
                         );
-                    }
+                    },
                 }
                 columns_inserted += 1;
                 if new_column_count > 0 && columns_inserted >= new_column_count {
@@ -1266,12 +1271,12 @@ fn map_computedvalue(
                 record.push_field("");
                 columns_inserted += 1;
             }
-        }
+        },
         _ => {
             return fail_clierror!(
                 "Unexpected value type returned by provided Luau expression. {computed_value:?}"
             );
-        }
+        },
     };
     Ok(())
 }
@@ -1425,7 +1430,7 @@ fn setup_helpers(
             "trace" => log::trace!("{log_msg}"),
             _ => {
                 log::info!("unknown log level: {log_level} msg: {log_msg}");
-            }
+            },
         }
         Ok(())
     })?;
@@ -1651,7 +1656,7 @@ fn setup_helpers(
                 Ok(headers) => headers.clone(),
                 Err(e) => {
                     return helper_err!("qsv_loadcsv", "Cannot read headers of CSV: {e}");
-                }
+                },
             };
 
             let key_idx = if key_column.is_empty() {
@@ -1667,7 +1672,7 @@ fn setup_helpers(
                             "qsv_loadcsv",
                             "Cannot find key column \"{key_column}\" in CSV."
                         );
-                    }
+                    },
                 }
             };
 
@@ -1854,10 +1859,10 @@ fn setup_helpers(
                 output_table.set("stderr", child_stderr)?;
 
                 Ok(output_table)
-            }
+            },
             Err(e) => {
                 helper_err!("qsv_cmd", "failed to execute qsv command: {qsv_args}: {e}")
-            }
+            },
         }
     })?;
     luau.globals().set("qsv_cmd", qsv_cmd)?;
@@ -1957,13 +1962,13 @@ fn setup_helpers(
                 output_table.set("stderr", child_stderr)?;
 
                 Ok(output_table)
-            }
+            },
             Err(e) => {
                 helper_err!(
                     "qsv_shellcmd",
                     "failed to execute shell command: {shellcmd_string} {args_string}: {e}"
                 )
-            }
+            },
         }
     })?;
     luau.globals().set("qsv_shellcmd", qsv_shellcmd)?;
