@@ -1,17 +1,18 @@
 static USAGE: &str = r#"
 Randomly samples CSV data uniformly using memory proportional to the size of
-the sample.
+the sample if no index is present, or constant memory if an index is present.
 
-When an index is present and a seed is not specified, this command will use 
-random indexing if the sample size is less than 10% of the total number of records.
+When an index is present, this command will use random indexing.
 This allows for efficient sampling such that the entire CSV file is not parsed.
 
+Otherwise, if no index is present, it will visit every CSV record exactly once,
+which is necessary to provide a uniform random sample (reservoir sampling).
+If you wish to limit the number of records visited, use the 'qsv slice' command
+to pipe into 'qsv sample'.
+
 This command is intended to provide a means to sample from a CSV data set that
 is too big to fit into memory (for example, for use with commands like 'qsv
-frequency' or 'qsv stats'). It will however visit every CSV record exactly
-once, which is necessary to provide a uniform random sample. If you wish to
-limit the number of records visited, use the 'qsv slice' command to pipe into
-'qsv sample'.
+frequency' or 'qsv stats'). 
 
 For examples, see https://github.com/jqnatividad/qsv/blob/master/tests/test_sample.rs.
 
@@ -26,8 +27,15 @@ sample arguments:
                            0 and 1 exclusive, it is treated as a percentage of
                            the CSV to sample (e.g. 0.20 is 20 percent).
 
+                           If an index is present, this command will
+                           use random indexing to sample efficiently. Otherwise,
+                           it will use reservoir sampling, which requires
+                           visiting every record in the CSV.
+
 sample options:
-    --seed <number>        Random number generator seed.
+    --seed <number>        Random Number Generator (RNG) seed.
+    --faster               Use a faster RNG that uses the Wyrand algorithm instead
+                           of the ChaCha algorithm used by the standard RNG.
     --user-agent <agent>   Specify custom user agent to use when the input is a URL.
                            It supports the following variables -
                            $QSV_VERSION, $QSV_TARGET, $QSV_BIN_NAME, $QSV_KIND and $QSV_COMMAND.
@@ -43,13 +51,13 @@ Common options:
                            the population to sample from. (When not set, the
                            first row is the header row and will always appear
                            in the output.)
-    -d, --delimiter <arg>  The field delimiter for reading CSV data.
+    -d, --delimiter <arg>  The field delimiter for reading/writing CSV data.
                            Must be a single character. (default: ,)
 "#;
 
 use std::io;
 
-use log::debug;
+use fastrand; //DevSkim: ignore DS148264
 use rand::{self, rngs::StdRng, seq::SliceRandom, Rng, SeedableRng};
 use serde::Deserialize;
 use tempfile::NamedTempFile;
@@ -57,7 +65,6 @@ use url::Url;
 
 use crate::{
     config::{Config, Delimiter},
-    index::Indexed,
     util, CliResult,
 };
 
@@ -69,6 +76,7 @@ struct Args {
     flag_no_headers: bool,
     flag_delimiter:  Option<Delimiter>,
     flag_seed:       Option<usize>,
+    flag_faster:     bool,
     flag_user_agent: Option<String>,
     flag_timeout:    Option<u16>,
 }
@@ -102,7 +110,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 // its a local file
                 Some(uri)
             }
-        }
+        },
         None => None,
     };
 
@@ -112,22 +120,47 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     let mut sample_size = args.arg_sample_size;
 
-    let mut wtr = Config::new(&args.flag_output).writer()?;
-    let sampled = if let Some(mut idx) = rconfig.indexed()? {
+    let mut wtr = Config::new(&args.flag_output)
+        .delimiter(args.flag_delimiter)
+        .writer()?;
+
+    if let Some(mut idx) = rconfig.indexed()? {
+        // the index is present, so we can use random indexing
         #[allow(clippy::cast_precision_loss)]
         if sample_size < 1.0 {
             sample_size *= idx.count() as f64;
         }
-        if args.flag_seed.is_none() && do_random_access(sample_size as u64, idx.count()) {
-            rconfig.write_headers(&mut *idx, &mut wtr)?;
-            sample_random_access(&mut idx, sample_size as u64)?
+        rconfig.write_headers(&mut *idx, &mut wtr)?;
+
+        let mut all_indices = (0..idx.count()).collect::<Vec<_>>();
+
+        if args.flag_faster {
+            log::info!(
+                "doing --faster sample_random_access. Seed: {:?}",
+                args.flag_seed
+            );
+            if let Some(seed) = args.flag_seed {
+                fastrand::seed(seed as u64); //DevSkim: ignore DS148264
+            }
+            all_indices = fastrand::choose_multiple(all_indices.into_iter(), sample_size as usize); //DevSkim: ignore DS148264
         } else {
-            let mut rdr = rconfig.reader()?;
-            rconfig.write_headers(&mut rdr, &mut wtr)?;
-            sample_reservoir(&mut rdr, sample_size as u64, args.flag_seed)?
+            log::info!(
+                "doing standard sample_random_access. Seed: {:?}",
+                args.flag_seed
+            );
+            let mut rng: StdRng = match args.flag_seed {
+                None => StdRng::from_rng(rand::thread_rng()).unwrap(),
+                Some(seed) => StdRng::seed_from_u64(seed as u64), //DevSkim: ignore DS148264
+            };
+            SliceRandom::shuffle(&mut *all_indices, &mut rng); //DevSkim: ignore DS148264
+        }
+
+        for i in all_indices.into_iter().take(sample_size as usize) {
+            idx.seek(i)?;
+            wtr.write_byte_record(&idx.byte_records().next().unwrap()?)?;
         }
     } else {
-        debug!("no index");
+        // the index is not present, so we have to do reservoir sampling
         #[allow(clippy::cast_precision_loss)]
         if sample_size < 1.0 {
             let Ok(row_count) = util::count_rows(&rconfig) else {
@@ -137,44 +170,26 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         }
         let mut rdr = rconfig.reader()?;
         rconfig.write_headers(&mut rdr, &mut wtr)?;
-        sample_reservoir(&mut rdr, sample_size as u64, args.flag_seed)?
+        let sampled = sample_reservoir(
+            &mut rdr,
+            sample_size as u64,
+            args.flag_seed,
+            args.flag_faster,
+        )?;
+        for row in sampled {
+            wtr.write_byte_record(&row)?;
+        }
     };
 
-    for row in sampled {
-        wtr.write_byte_record(&row)?;
-    }
     Ok(wtr.flush()?)
 }
 
-fn sample_random_access<R, I>(
-    idx: &mut Indexed<R, I>,
-    sample_size: u64,
-) -> CliResult<Vec<csv::ByteRecord>>
-where
-    R: io::Read + io::Seek,
-    I: io::Read + io::Seek,
-{
-    debug!("doing sample_random_access");
-    let mut all_indices = (0..idx.count()).collect::<Vec<_>>();
-    let mut rng = ::rand::thread_rng();
-    // this non-cryptographic shuffle is sufficient for our use case
-    // as we're optimizing for performance. Add DevSkim lint ignore.
-    SliceRandom::shuffle(&mut *all_indices, &mut rng); //DevSkim: ignore DS148264
-
-    let mut sampled = Vec::with_capacity(sample_size as usize);
-    for i in all_indices.into_iter().take(sample_size as usize) {
-        idx.seek(i)?;
-        sampled.push(idx.byte_records().next().unwrap()?);
-    }
-    Ok(sampled)
-}
-
 fn sample_reservoir<R: io::Read>(
     rdr: &mut csv::Reader<R>,
     sample_size: u64,
     seed: Option<usize>,
+    faster: bool,
 ) -> CliResult<Vec<csv::ByteRecord>> {
-    debug!("doing sample_reservoir");
     // The following algorithm has been adapted from:
     // https://en.wikipedia.org/wiki/Reservoir_sampling
     let mut reservoir = Vec::with_capacity(sample_size as usize);
@@ -183,26 +198,37 @@ fn sample_reservoir<R: io::Read>(
         reservoir.push(row?);
     }
 
-    // Seeding RNG
-    let mut rng: StdRng = match seed {
-        None => StdRng::from_rng(rand::thread_rng()).unwrap(),
-        // the non-cryptographic seed_from_u64 is sufficient for our use case
-        // as we're optimizing for performance
-        Some(seed) => StdRng::seed_from_u64(seed as u64), //DevSkim: ignore DS148264
-    };
+    if faster {
+        log::info!("doing --faster sample_reservoir. Seed: {seed:?}");
+        if let Some(seed) = seed {
+            fastrand::seed(seed as u64); //DevSkim: ignore DS148264
+        }
 
-    // Now do the sampling.
-    for (i, row) in records {
-        let random = rng.gen_range(0..=i);
-        if random < sample_size as usize {
-            reservoir[random] = row?;
+        let mut random: usize;
+        for (i, row) in records {
+            random = fastrand::usize(0..=i); //DevSkim: ignore DS148264
+            if random < sample_size as usize {
+                reservoir[random] = row?;
+            }
+        }
+    } else {
+        log::info!("doing standard sample_reservoir. Seed: {seed:?}");
+        // Seeding RNG
+        let mut rng: StdRng = match seed {
+            None => StdRng::from_rng(rand::thread_rng()).unwrap(),
+            // the non-cryptographic seed_from_u64 is sufficient for our use case
+            // as we're optimizing for performance
+            Some(seed) => StdRng::seed_from_u64(seed as u64), //DevSkim: ignore DS148264
+        };
+
+        let mut random: usize;
+        // Now do the sampling.
+        for (i, row) in records {
+            random = rng.gen_range(0..=i);
+            if random < sample_size as usize {
+                reservoir[random] = row?;
+            }
         }
     }
     Ok(reservoir)
 }
-
-fn do_random_access(sample_size: u64, total: u64) -> bool {
-    let raflag = sample_size <= (total / 10);
-    debug!("sample_size: {sample_size}, total: {total}, raflag: {raflag}");
-    raflag
-}
