@@ -153,7 +153,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 return fail_clierror!(
                     "Failed to infer schema via stats and frequency from {input_filename}: {e}"
                 );
-            }
+            },
         };
 
     // generate regex pattern for selected String columns
@@ -315,7 +315,7 @@ pub fn infer_schema_from_stats(args: &Args, input_filename: &str) -> CliResult<M
                         enum_list.push(Value::String(value.to_string()));
                     }
                 }
-            }
+            },
             "Integer" => {
                 type_list.push(Value::String("integer".to_string()));
 
@@ -336,12 +336,12 @@ pub fn infer_schema_from_stats(args: &Args, input_filename: &str) -> CliResult<M
                         enum_list.push(Value::Number(Number::from(int_value)));
                     }
                 }
-            }
+            },
             "Float" => {
                 type_list.push(Value::String("number".to_string()));
 
                 if let Some(min_str) = stats_record.get(stats_col_index_map["min"]) {
-                    let min = min_str.parse::<f64>().unwrap();
+                    let min = fast_float::parse::<f64, _>(min_str).unwrap();
                     field_map.insert(
                         "minimum".to_string(),
                         Value::Number(Number::from_f64(min).unwrap()),
@@ -349,35 +349,35 @@ pub fn infer_schema_from_stats(args: &Args, input_filename: &str) -> CliResult<M
                 };
 
                 if let Some(max_str) = stats_record.get(stats_col_index_map["max"]) {
-                    let max = max_str.parse::<f64>().unwrap();
+                    let max = fast_float::parse::<f64, _>(max_str).unwrap();
                     field_map.insert(
                         "maximum".to_string(),
                         Value::Number(Number::from_f64(max).unwrap()),
                     );
                 };
-            }
+            },
             "NULL" => {
                 type_list.push(Value::String("null".to_string()));
-            }
+            },
             "Date" => {
                 type_list.push(Value::String("string".to_string()));
 
                 if args.flag_strict_dates {
                     field_map.insert("format".to_string(), Value::String("date".to_string()));
                 }
-            }
+            },
             "DateTime" => {
                 type_list.push(Value::String("string".to_string()));
 
                 if args.flag_strict_dates {
                     field_map.insert("format".to_string(), Value::String("date-time".to_string()));
                 }
-            }
+            },
             _ => {
                 wwarn!("Stats gave unexpected field type '{col_type}', default to JSON String.");
                 // defaults to JSON String
                 type_list.push(Value::String("string".to_string()));
-            }
+            },
         }
 
         if col_null_count > 0 && !type_list.contains(&Value::String("null".to_string())) {
@@ -474,10 +474,10 @@ fn get_stats_records(args: &Args) -> CliResult<(ByteRecord, Vec<Stats>, AHashMap
             Ok(stats) => {
                 csv_stats = stats;
                 stats_bin_loaded = true;
-            }
+            },
             Err(e) => {
                 wwarn!("Error reading stats.csv.bin file: {e:?}. Regenerating stats.bin file.");
-            }
+            },
         }
     }
 
@@ -544,12 +544,12 @@ fn get_stats_records(args: &Args) -> CliResult<(ByteRecord, Vec<Stats>, AHashMap
         match bincode::deserialize_from(&mut bin_file) {
             Ok(stats) => {
                 csv_stats = stats;
-            }
+            },
             Err(e) => {
                 return fail_clierror!(
                     "Error reading stats.csv.bin file: {e:?}. Schema generation aborted."
                 );
-            }
+            },
         }
     };
 
@@ -734,36 +734,41 @@ fn generate_string_patterns(
 
     #[allow(unused_assignments)]
     let mut record = csv::ByteRecord::new();
+    let mut header_byte_slice: &[u8];
+    let mut header_string: String;
+    let mut value_string: String;
+
     while rdr.read_byte_record(&mut record)? {
         for (i, value_byte_slice) in sel.select(&record).enumerate() {
             // get header based on column index in Selection array
-            let header_byte_slice: &[u8] = headers.get(sel[i]).unwrap();
+            header_byte_slice = headers.get(sel[i]).unwrap();
 
             // convert header and value byte arrays to UTF8 strings
-            let header_string: String = convert_to_string(header_byte_slice)?;
+            header_string = convert_to_string(header_byte_slice)?;
 
             // pattern validation only applies to String type, so skip if not String
             if !should_emit_pattern_constraint(&properties_map[&header_string]) {
                 continue;
             }
 
-            let value_string: String = convert_to_string(value_byte_slice)?;
+            value_string = convert_to_string(value_byte_slice)?;
 
-            let set = unique_values_map
-                .entry(header_string)
-                .or_insert_with(HashSet::<String>::new);
+            let set = unique_values_map.entry(header_string).or_default();
             set.insert(value_string);
         }
     }
 
     // build regex pattern for each header
     pattern_map.reserve(unique_values_map.len());
+    let mut values: Vec<&String>;
+    let mut regexp: String;
+
     for (header, value_set) in &unique_values_map {
         // Convert Set to Vector
-        let values: Vec<&String> = Vec::from_iter(value_set);
+        values = Vec::from_iter(value_set);
 
         // build regex based on unique values
-        let regexp: String = RegExpBuilder::from(&values)
+        regexp = RegExpBuilder::from(&values)
             .with_conversion_of_repetitions()
             .with_minimum_repetitions(2)
             .build();
