@@ -2,7 +2,7 @@ static USAGE: &str = r#"
 Run blazing-fast Polars SQL queries against several CSVs - replete with joins, aggregations,
 grouping, sorting, and more - working on larger than memory CSV files.
 
-Polars SQL is a subset of ANSI SQL, converting SQL queries to fast Polars LazyFrame expressions
+Polars SQL is a SQL dialect, converting SQL queries to fast Polars LazyFrame expressions
 (see https://pola-rs.github.io/polars-book/user-guide/sql/intro/).
 
 For a list of SQL functions and keywords supported by Polars SQL, see
@@ -16,7 +16,7 @@ Example queries:
 
   qsv sqlp data.csv 'select * from data where col1 > 10 order by col2 desc limit 20'
 
-  qsv sqlp data.csv 'select col1, col2, col3 as friendlyname from data' --format parquet --output data.parquet
+  qsv sqlp data.csv 'select col1, col2 as friendlyname from data' --format parquet --output data.parquet
 
   qsv sqlp data.csv data2.csv 'select * from data join data2 on data.colname = data2.colname'
 
@@ -24,14 +24,27 @@ Example queries:
 
   qsv sqlp data.csv 'SELECT col1, count(*) AS cnt FROM data GROUP BY col1 ORDER BY cnt DESC, col1 ASC'
 
+  qsv sqlp data.csv "select lower(col1), substr(col2, 2, 4) from data WHERE starts_with(col1, 'foo')"
+
+  # Use a SQL script to run a long, complex SQL query or to run SEVERAL SQL queries.
+  # When running several queries, each query needs to be separated by a semicolon,
+  # the last query will be returned as the result.
+  # Typically, earlier queries are used to create tables that can be used in later queries.
+  # See test_sqlp/sqlp_boston311_sql_script() for an example.
   qsv sqlp data.csv data2.csv data3.csv data4.csv script.sql --format json --output data.json
 
-  qsv sqlp data.csv "select lower(col1), substr(col2, 2, 4) from data WHERE starts_with(col1, 'foo')"
+  # use Common Table Expressions (CTEs) using WITH to simplify complex queries
+  qsv sqlp people.csv "WITH millenials AS (SELECT * FROM people WHERE age >= 25 and age <= 40) \
+    SELECT * FROM millenials WHERE STARTS_WITH(name,'C')"
+
+  # CASE statement
+  qsv sqlp data.csv "select CASE WHEN col1 > 10 THEN 'foo' WHEN col1 > 5 THEN 'bar' ELSE 'baz' END from data"
+  qsv sqlp data.csv "select CASE col*5 WHEN 10 THEN 'foo' WHEN 5 THEN 'bar' ELSE 'baz' END from _t_1"
 
   # spaceship operator: "<=>" (three-way comparison operator)
   #  returns -1 if left < right, 0 if left == right, 1 if left > right
   # https://en.wikipedia.org/wiki/Three-way_comparison#Spaceship_operator
-  qsv sqlp data.csv data2.csv "select data.col2 <=> data2.col2 from data join data2 on data.col1 = data2.col1"
+  qsv sqlp data.csv data2.csv "select data.c2 <=> data2.c2 from data join data2 on data.c1 = data2.c1"
 
   # regex operators: "~" (contains pattern, case-sensitive); "~*" (contains pattern, case-insensitive)
   #   "!~" (does not contain pattern, case-sensitive); "!~*" (does not contain pattern, case-insensitive)
@@ -46,13 +59,21 @@ Example queries:
   # case-insensitive regexp_like
   qsv sqlp data.csv "select * from data WHERE regexp_like(col1, '^foo', 'i') AND col2 > 10"
 
-  qsv sqlp data.csv "select data.col1, t2.col1 from data join read_parquet('data2.parquet') as t2 ON data.col1 = t2.col1"
-  qsv sqlp data.csv "select data.col1, t2.col1 from data join read_ndjson('data2.jsonl') as t2 on data.col1 = t2.col1"
-  qsv sqlp data.csv "select data.col1, t2.col1 from data join read_ipc('data2.arrow') as t2 ON data.col1 = t2.col1"
+  # use Parquet, JSONL and Arrow files in SQL queries
+  qsv sqlp data.csv "select * from data join read_parquet('data2.parquet') as t2 ON data.c1 = t2.c1"
+  qsv sqlp data.csv "select * from data join read_ndjson('data2.jsonl') as t2 on data.c1 = t2.c1"
+  qsv sqlp data.csv "select * from data join read_ipc('data2.arrow') as t2 ON data.c1 = t2.c1"
 
+  # use stdin as input
   cat data.csv | qsv sqlp - 'select * from stdin'
   cat data.csv | qsv sqlp - data2.csv 'select * from stdin join data2 on stdin.col1 = data2.col1'
 
+  # automatic snappy decompression/compression
+  qsv sqlp data.csv.sz 'select * from data where col1 > 10' --output result.csv.sz
+
+  # explain query plan
+  qsv sqlp data.csv 'explain select * from data where col1 > 10 order by col2 desc limit 20'
+
 For more examples, see https://github.com/jqnatividad/qsv/blob/master/tests/test_sqlp.rs.
 
 Usage:
@@ -72,8 +93,8 @@ sqlp arguments:
                            named after the file name (without the extension), or as "_t_N"
                            where N is the 1-based index.
                            If the input ends with ".sql", the input will be read as a SQL script file,
-                           with each SQL statement separated by a semicolon. It will execute the
-                           statements in order, and the result of the LAST statement will be returned.
+                           with each SQL query separated by a semicolon. It will execute the queries
+                           in order, and the result of the LAST query will be returned as the result.
 
 sqlp options:
     --format <arg>            The output format to use. Valid values are:
@@ -92,6 +113,8 @@ sqlp options:
     --low-memory              Use low memory mode when parsing CSVs. This will use less memory
                               but will be slower. It will also process LazyFrames in streaming mode.
                               Only use this when you get out of memory errors.
+    --no-optimizations        Disable non-default query optimizations. This will make queries slower.
+                              Only use this when you get query errors.
     --ignore-errors           Ignore errors when parsing CSVs. If set, rows with errors
                               will be skipped. If not set, the query will fail.
                               Only use this when debugging queries, as polars does batched
@@ -164,24 +187,25 @@ static DEFAULT_ZSTD_COMPRESSION_LEVEL: i32 = 3;
 
 #[derive(Deserialize, Clone)]
 struct Args {
-    arg_input:            Vec<PathBuf>,
-    arg_sql:              String,
-    flag_format:          String,
-    flag_try_parsedates:  bool,
-    flag_infer_len:       usize,
-    flag_low_memory:      bool,
-    flag_ignore_errors:   bool,
-    flag_datetime_format: Option<String>,
-    flag_date_format:     Option<String>,
-    flag_time_format:     Option<String>,
-    flag_float_precision: Option<usize>,
-    flag_null_value:      String,
-    flag_compression:     String,
-    flag_compress_level:  Option<i32>,
-    flag_statistics:      bool,
-    flag_output:          Option<String>,
-    flag_delimiter:       Option<Delimiter>,
-    flag_quiet:           bool,
+    arg_input:             Vec<PathBuf>,
+    arg_sql:               String,
+    flag_format:           String,
+    flag_try_parsedates:   bool,
+    flag_infer_len:        usize,
+    flag_low_memory:       bool,
+    flag_no_optimizations: bool,
+    flag_ignore_errors:    bool,
+    flag_datetime_format:  Option<String>,
+    flag_date_format:      Option<String>,
+    flag_time_format:      Option<String>,
+    flag_float_precision:  Option<usize>,
+    flag_null_value:       String,
+    flag_compression:      String,
+    flag_compress_level:   Option<i32>,
+    flag_statistics:       bool,
+    flag_output:           Option<String>,
+    flag_delimiter:        Option<Delimiter>,
+    flag_quiet:            bool,
 }
 
 #[derive(Default, Clone)]
@@ -219,7 +243,7 @@ impl OutputMode {
                 Some(x) => {
                     let path = Path::new(&x);
                     Box::new(File::create(path)?) as Box<dyn Write>
-                }
+                },
                 None => Box::new(io::stdout()) as Box<dyn Write>,
             };
             let mut w = io::BufWriter::with_capacity(256_000, w);
@@ -250,13 +274,13 @@ impl OutputMode {
                                 .unwrap_or_else(|| DEFAULT_GZIP_COMPRESSION_LEVEL.into())
                                 as u8;
                             ParquetCompression::Gzip(Some(GzipLevel::try_new(gzip_level)?))
-                        }
+                        },
                         PqtCompression::Zstd => {
                             let zstd_level = args
                                 .flag_compress_level
                                 .unwrap_or(DEFAULT_ZSTD_COMPRESSION_LEVEL);
                             ParquetCompression::Zstd(Some(ZstdLevel::try_new(zstd_level)?))
-                        }
+                        },
                     };
 
                     ParquetWriter::new(&mut w)
@@ -265,7 +289,7 @@ impl OutputMode {
                         .with_compression(parquet_compression)
                         .finish(&mut df)
                         .map(|_| ())
-                }
+                },
                 OutputMode::Arrow => IpcWriter::new(&mut w).finish(&mut df),
                 OutputMode::None => Ok(()),
             };
@@ -275,10 +299,10 @@ impl OutputMode {
         };
 
         match execute_inner() {
-            Ok(_) => Ok(df.shape()),
+            Ok(()) => Ok(df.shape()),
             Err(e) => {
                 fail_clierror!("Failed to execute query: {query}: {e}")
-            }
+            },
         }
     }
 }
@@ -353,25 +377,37 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         Some(args.flag_infer_len)
     };
 
-    let optimize_all = polars::lazy::frame::OptState {
-        projection_pushdown:        true,
-        predicate_pushdown:         true,
-        type_coercion:              true,
-        simplify_expr:              true,
-        file_caching:               !args.flag_low_memory,
-        slice_pushdown:             true,
-        common_subplan_elimination: true,
-        streaming:                  args.flag_low_memory,
+    let optimization_state = if args.flag_no_optimizations {
+        // use default optimization state
+        polars::lazy::frame::OptState {
+            file_caching: !args.flag_low_memory,
+            streaming: args.flag_low_memory,
+            ..Default::default()
+        }
+    } else {
+        polars::lazy::frame::OptState {
+            projection_pushdown: true,
+            predicate_pushdown:  true,
+            type_coercion:       true,
+            simplify_expr:       true,
+            file_caching:        !args.flag_low_memory,
+            slice_pushdown:      true,
+            comm_subplan_elim:   true,
+            comm_subexpr_elim:   true,
+            streaming:           args.flag_low_memory,
+        }
     };
+    log::debug!("Optimization state: {optimization_state:?}");
 
     let mut ctx = SQLContext::new();
     let mut table_aliases = HashMap::with_capacity(args.arg_input.len());
     let mut lossy_table_name = Cow::default();
+    let mut table_name;
 
     for (idx, table) in args.arg_input.iter().enumerate() {
         // as we are using the table name as alias, we need to make sure that the table name is a
         // valid identifier. if its not utf8, we use the lossy version
-        let table_name = Path::new(table)
+        table_name = Path::new(table)
             .file_stem()
             .and_then(std::ffi::OsStr::to_str)
             .unwrap_or_else(|| {
@@ -400,7 +436,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             .with_ignore_errors(args.flag_ignore_errors)
             .low_memory(args.flag_low_memory)
             .finish()?;
-        ctx.register(table_name, lf.with_optimizations(optimize_all));
+        ctx.register(table_name, lf.with_optimizations(optimization_state));
     }
 
     if log::log_enabled!(log::Level::Debug) {
@@ -430,20 +466,21 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     let num_queries = queries.len();
     let last_query: usize = num_queries.saturating_sub(1);
+    let mut is_last_query;
+    let mut current_query = String::new();
     let mut query_result_shape = (0_usize, 0_usize);
     let mut now = Instant::now();
 
     for (idx, query) in queries.iter().enumerate() {
         // check if this is the last query in the script
-        let is_last_query = idx == last_query;
+        is_last_query = idx == last_query;
 
         // replace aliases in query
-        let mut current_query = query.to_string();
+        current_query.clone_from(query);
         for (table_name, table_alias) in &table_aliases {
             // we quote the table name to avoid issues with reserved keywords and
             // other characters that are not allowed in identifiers
-            let quoted_table_name = format!(r#""{table_name}""#);
-            current_query = current_query.replace(table_alias, &quoted_table_name);
+            current_query = current_query.replace(table_alias, &(format!(r#""{table_name}""#)));
         }
 
         if log::log_enabled!(log::Level::Debug) {
