@@ -9,7 +9,7 @@ statistics requires loading the entire file into memory, so they must be enabled
 By default, the following statistics are reported for *every* column in the CSV data:
 sum, min/max/range values, min/max length, mean, stddev, variance, nullcount & sparsity.
 The default set of statistics corresponds to statistics that can be computed efficiently
-on a stream of data (i.e., constant memory) and can work with arbitrarily large CSV files.
+on a stream of data (i.e., constant memory) and works with arbitrarily large CSV files.
 
 The following additional statistics require loading the entire file into memory:
 cardinality, mode/antimode, median, MAD, quartiles and its related measures (IQR,
@@ -188,7 +188,8 @@ use crate::{
     util, CliResult,
 };
 
-#[derive(Clone, Deserialize, Debug)]
+#[allow(clippy::unsafe_derive_deserialize)]
+#[derive(Clone, Deserialize)]
 pub struct Args {
     pub arg_input:            Option<String>,
     pub flag_select:          SelectColumns,
@@ -380,7 +381,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         fs::remove_file(&stats_file)?;
                         fs::remove_file(&stats_args_json_file)?;
                         String::new()
-                    }
+                    },
                 };
 
             // deserialize the existing stats args json
@@ -395,7 +396,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         stat_args.date_generated = String::new();
                         stat_args.compute_duration_ms = 0;
                         stat_args
-                    }
+                    },
                     Err(e) => {
                         log::warn!(
                             "Could not serialize {path_file_stem}.stats.csv.json: {e:?}, \
@@ -404,7 +405,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         fs::remove_file(&stats_file)?;
                         fs::remove_file(&stats_args_json_file)?;
                         StatsArgs::default()
-                    }
+                    },
                 };
 
             // check if the cached stats are current (ie the stats file is newer than the input
@@ -472,7 +473,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     } else {
                         args.parallel_stats(&args.flag_dates_whitelist, idx_count)
                     }
-                }
+                },
             }?;
 
             // clone a copy of stats so we can binary encode it to disk later
@@ -701,23 +702,24 @@ impl Args {
     where
         I: Iterator<Item = csv::Result<csv::ByteRecord>>,
     {
-        let sel_len = sel.len();
-
-        let mut stats = self.new_stats(sel_len);
-        assert!(stats.len() == sel_len);
+        let mut stats = self.new_stats(sel.len());
 
+        // safety: we know INFER_DATE_FLAGS is Some because we called init_date_inference
         let infer_date_flags = INFER_DATE_FLAGS.get().unwrap();
-        assert!(infer_date_flags.len() == sel_len);
+        // so we don't need to get flag_infer_boolean from big args struct for each iteration
+        let infer_boolean = self.flag_infer_boolean;
 
-        // safety: the asserts above guarantee that the following unwraps are safe
-        // and doesn't require a bounds check.
-        for row in it {
-            for (i, field) in sel.select(&row.unwrap()).enumerate() {
-                stats.get_mut(i).unwrap().add(
-                    field,
-                    *infer_date_flags.get(i).unwrap(),
-                    self.flag_infer_boolean,
-                );
+        // safety: because we're using iterators and INFER_DATE_FLAGS has the same size,
+        // we know we don't need to bounds check
+        unsafe {
+            for row in it {
+                for (i, field) in sel.select(&row.unwrap_unchecked()).enumerate() {
+                    stats.get_unchecked_mut(i).add(
+                        field,
+                        *infer_date_flags.get_unchecked(i),
+                        infer_boolean,
+                    );
+                }
             }
         }
         stats
@@ -864,47 +866,48 @@ fn init_date_inference(
     headers: &csv::ByteRecord,
     flag_whitelist: &str,
 ) -> Result<(), String> {
-    if infer_dates {
-        let dmy_preferred = prefer_dmy || util::get_envvar_flag("QSV_PREFER_DMY");
-        DMY_PREFERENCE.store(dmy_preferred, Ordering::Relaxed);
-
-        let whitelist_lower = flag_whitelist.to_lowercase();
-        log::info!("inferring dates with date-whitelist: {whitelist_lower}");
-
-        if whitelist_lower == "all" {
-            log::info!("inferring dates for ALL fields with DMY preference: {dmy_preferred}");
-            if let Err(e) = INFER_DATE_FLAGS.set(vec![true; headers.len()]) {
-                return fail_format!("Cannot init date inference flags for ALL fields: {e:?}");
-            };
-        } else {
-            let whitelist = whitelist_lower
-                .split(',')
-                .map(|s| s.trim().to_string())
-                .collect_vec();
-
-            let mut infer_date_flags: Vec<bool> = Vec::with_capacity(headers.len());
-            for header in headers {
-                let header_str = from_bytes::<String>(header).unwrap().to_lowercase();
-                let mut date_found = false;
-                for whitelist_item in &whitelist {
-                    if header_str.contains(whitelist_item) {
-                        date_found = true;
-                        log::info!(
-                            "inferring dates for {header_str} with DMY preference: {dmy_preferred}"
-                        );
-                        break;
-                    }
-                }
-                infer_date_flags.push(date_found);
-            }
-            if let Err(e) = INFER_DATE_FLAGS.set(infer_date_flags) {
-                return fail_format!("Cannot init date inference flags: {e:?}");
-            };
-        }
-    // we're not inferring dates, set INFER_DATE_FLAGS to all false
-    } else if let Err(e) = INFER_DATE_FLAGS.set(vec![false; headers.len()]) {
-        return fail_format!("Cannot init empty date inference flags: {e:?}");
+    if !infer_dates {
+        // we're not inferring dates, set INFER_DATE_FLAGS to all false
+        INFER_DATE_FLAGS
+            .set(vec![false; headers.len()])
+            .map_err(|e| format!("Cannot init empty date inference flags: {e:?}"))?;
+        return Ok(());
     }
+
+    let dmy_preferred = prefer_dmy || util::get_envvar_flag("QSV_PREFER_DMY");
+    DMY_PREFERENCE.store(dmy_preferred, Ordering::Relaxed);
+
+    let whitelist_lower = flag_whitelist.to_lowercase();
+    log::info!("inferring dates with date-whitelist: {whitelist_lower}");
+
+    let infer_date_flags = if whitelist_lower == "all" {
+        log::info!("inferring dates for ALL fields with DMY preference: {dmy_preferred}");
+        vec![true; headers.len()]
+    } else {
+        let whitelist = whitelist_lower
+            .split(',')
+            .map(str::trim)
+            .collect::<Vec<_>>();
+        headers
+            .iter()
+            .map(|header| {
+                let header_str = from_bytes::<String>(header).unwrap().to_lowercase();
+                let date_found = whitelist
+                    .iter()
+                    .any(|whitelist_item| header_str.contains(whitelist_item));
+                if date_found {
+                    log::info!(
+                        "inferring dates for {header_str} with DMY preference: {dmy_preferred}"
+                    );
+                }
+                date_found
+            })
+            .collect()
+    };
+
+    INFER_DATE_FLAGS
+        .set(infer_date_flags)
+        .map_err(|e| format!("Cannot init date inference flags: {:?}", e))?;
     Ok(())
 }
 
@@ -929,7 +932,7 @@ impl Commute for WhichStats {
     }
 }
 
-#[derive(Clone, Serialize, Deserialize, Debug, PartialEq)]
+#[derive(Clone, Serialize, Deserialize, PartialEq)]
 pub struct Stats {
     typ:       FieldType,
     sum:       Option<TypedSum>,
@@ -1036,7 +1039,7 @@ impl Stats {
                         v.add_null();
                     };
                 }
-            }
+            },
             TFloat | TInteger => {
                 if sample_type == TNull {
                     if self.which.include_nulls {
@@ -1056,10 +1059,12 @@ impl Stats {
                         v.add(n);
                     }
                     if let Some(v) = self.online.as_mut() {
-                        v.add(n);
+                        v.add(&n);
                     }
                 }
-            }
+            },
+            // do nothing for String type
+            TString => {},
             TDateTime | TDate => {
                 if sample_type == TNull {
                     if self.which.include_nulls {
@@ -1084,12 +1089,10 @@ impl Stats {
                         v.add(n);
                     }
                     if let Some(v) = self.online.as_mut() {
-                        v.add(n);
+                        v.add(&n);
                     }
                 }
-            }
-            // do nothing for String type
-            TString => {}
+            },
         }
     }
 
@@ -1120,7 +1123,7 @@ impl Stats {
                 if self.which.mode {
                     mc_pieces.extend_from_slice(&[empty(), empty(), empty(), empty()]);
                 }
-            }
+            },
             Some(ref mut v) => {
                 if self.which.cardinality {
                     cardinality = v.cardinality();
@@ -1182,7 +1185,7 @@ impl Stats {
                         ]);
                     }
                 }
-            }
+            },
         }
 
         // min/max/range
@@ -1227,7 +1230,7 @@ impl Stats {
         // sum
         if let Some(sum) = self.sum.as_ref().and_then(|sum| sum.show(typ)) {
             if typ == FieldType::TFloat {
-                if let Ok(f64_val) = sum.parse::<f64>() {
+                if let Ok(f64_val) = fast_float::parse::<f64, _>(&sum) {
                     pieces.push(util::round_num(f64_val, round_places));
                 } else {
                     pieces.push(format!("ERROR: Cannot convert {sum} to a float."));
@@ -1354,7 +1357,7 @@ impl Stats {
                         empty(),
                     ]);
                 }
-            }
+            },
             Some((q1, q2, q3)) => {
                 let iqr = q3 - q1;
 
@@ -1413,7 +1416,7 @@ impl Stats {
                     ]);
                 }
                 pieces.push(util::round_num(skewness, round_places));
-            }
+            },
         }
 
         // mode/modes/antimodes & cardinality
@@ -1455,17 +1458,19 @@ enum FieldType {
 }
 
 impl FieldType {
-    // infer data type
+    // infer data type from a given sample & current type inference
     // infer_dates signals if date inference should be attempted
-    // from a given sample & current type inference
+    // returns the inferred type and if infer_dates is true,
+    // the date in ms since the epoch if the type is a date or datetime
+    // otherwise, None
     #[inline]
     pub fn from_sample(
         infer_dates: bool,
         sample: &[u8],
         current_type: FieldType,
     ) -> (FieldType, Option<i64>) {
-        #[allow(clippy::len_zero)]
-        if sample.len() == 0 {
+        // faster than sample.len() == 0 or sample.is_empty() per microbenchmarks
+        if b"" == sample {
             return (TNull, None);
         }
         // no need to do type checking if current_type is already a String
@@ -1484,14 +1489,14 @@ impl FieldType {
             || current_type == FieldType::TNull
         {
             if let Ok(int_val) = string.parse::<i64>() {
-                // leading zero, its a string
+                // leading zero, its a string (e.g. zip codes)
                 if string.starts_with('0') && int_val != 0 {
                     return (TString, None);
                 }
                 return (TInteger, None);
             }
 
-            if string.parse::<f64>().is_ok() {
+            if fast_float::parse::<f64, _>(string).is_ok() {
                 return (TFloat, None);
             }
         }
@@ -1569,7 +1574,7 @@ impl fmt::Debug for FieldType {
 
 /// `TypedSum` keeps a rolling sum of the data seen.
 /// It sums integers until it sees a float, at which point it sums floats.
-#[derive(Clone, Default, Serialize, Deserialize, Debug, PartialEq)]
+#[derive(Clone, Default, Serialize, Deserialize, PartialEq)]
 struct TypedSum {
     integer: i64,
     float:   Option<f64>,
@@ -1578,8 +1583,7 @@ struct TypedSum {
 impl TypedSum {
     #[inline]
     fn add(&mut self, typ: FieldType, sample: &[u8]) {
-        #[allow(clippy::len_zero)]
-        if sample.len() == 0 {
+        if b"" == sample {
             return;
         }
         #[allow(clippy::cast_precision_loss)]
@@ -1589,12 +1593,12 @@ impl TypedSum {
                 match self.float {
                     None => {
                         self.float = Some((self.integer as f64) + float);
-                    }
+                    },
                     Some(ref mut f) => {
                         *f += float;
-                    }
+                    },
                 }
-            }
+            },
             TInteger => {
                 if let Some(ref mut float) = self.float {
                     *float += from_bytes::<f64>(sample).unwrap();
@@ -1604,8 +1608,8 @@ impl TypedSum {
                         .integer
                         .saturating_add(from_bytes::<i64>(sample).unwrap());
                 }
-            }
-            _ => {}
+            },
+            _ => {},
         }
     }
 
@@ -1621,13 +1625,13 @@ impl TypedSum {
                     _ => {
                         let mut buffer = itoa::Buffer::new();
                         Some(buffer.format(self.integer).to_owned())
-                    }
+                    },
                 }
-            }
+            },
             TFloat => {
                 let mut buffer = ryu::Buffer::new();
                 Some(buffer.format(self.float.unwrap_or(0.0)).to_owned())
-            }
+            },
         }
     }
 }
@@ -1647,7 +1651,7 @@ impl Commute for TypedSum {
 
 /// `TypedMinMax` keeps track of minimum/maximum/range values for each possible type
 /// where min/max/range makes sense.
-#[derive(Clone, Default, Serialize, Deserialize, Debug, PartialEq)]
+#[derive(Clone, Default, Serialize, Deserialize, PartialEq)]
 struct TypedMinMax {
     strings:  MinMax<Vec<u8>>,
     str_len:  MinMax<usize>,
@@ -1667,23 +1671,23 @@ impl TypedMinMax {
         self.strings.add(sample.to_vec());
         // safety: we can use unwrap below since we know the data type of the sample
         match typ {
-            TString | TNull => {}
+            TString | TNull => {},
             TFloat => {
-                let n = from_utf8(sample).unwrap().parse::<f64>().unwrap();
+                let n = fast_float::parse::<f64, _>(from_utf8(sample).unwrap()).unwrap();
 
                 self.floats.add(n);
                 self.integers.add(n as i64);
-            }
+            },
             TInteger => {
                 let n = from_utf8(sample).unwrap().parse::<i64>().unwrap();
                 self.integers.add(n);
                 #[allow(clippy::cast_precision_loss)]
                 self.floats.add(n as f64);
-            }
+            },
             TDate | TDateTime => {
                 let n = from_utf8(sample).unwrap().parse::<i64>().unwrap();
                 self.dates.add(n);
-            }
+            },
         }
     }
 
@@ -1711,7 +1715,7 @@ impl TypedMinMax {
                 } else {
                     None
                 }
-            }
+            },
             TInteger => {
                 if let (Some(min), Some(max)) = (self.integers.min(), self.integers.max()) {
                     let mut buffer = itoa::Buffer::new();
@@ -1723,7 +1727,7 @@ impl TypedMinMax {
                 } else {
                     None
                 }
-            }
+            },
             TFloat => {
                 if let (Some(min), Some(max)) = (self.floats.min(), self.floats.max()) {
                     let mut buffer = ryu::Buffer::new();
@@ -1735,7 +1739,7 @@ impl TypedMinMax {
                 } else {
                     None
                 }
-            }
+            },
             TDateTime | TDate => {
                 if let (Some(min), Some(max)) = (self.dates.min(), self.dates.max()) {
                     Some((
@@ -1751,7 +1755,7 @@ impl TypedMinMax {
                 } else {
                     None
                 }
-            }
+            },
         }
     }
 }
