@@ -171,7 +171,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         "{} columns (\"{field_list}\") and ",
                         header_len.separate_with_commas()
                     );
-                }
+                },
                 Err(e) => {
                     if args.flag_json || args.flag_pretty_json {
                         let header_error = json!({
@@ -189,7 +189,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         return fail!(json_error);
                     }
                     return fail_clierror!("Cannot read header ({e}).");
-                }
+                },
             }
         }
 
@@ -280,17 +280,17 @@ Use `qsv input` to fix formatting and to transcode to utf8 if required."#
                             Ok(schema) => (json, schema),
                             Err(e) => {
                                 return fail_clierror!("Cannot compile schema json. error: {e}");
-                            }
+                            },
                         }
-                    }
+                    },
                     Err(e) => {
                         return fail_clierror!("Unable to parse schema json. error: {e}");
-                    }
+                    },
                 }
-            }
+            },
             Err(e) => {
                 return fail_clierror!("Unable to retrieve json. error: {e}");
-            }
+            },
         };
 
     debug!("compiled schema: {:?}", &schema_compiled);
@@ -335,10 +335,10 @@ Use `qsv input` to fix formatting and to transcode to utf8 if required."#
                         // nothing else to add to batch
                         break;
                     }
-                }
+                },
                 Err(e) => {
                     return fail_clierror!("Error reading row: {row_number}: {e}");
-                }
+                },
             }
         }
 
@@ -532,7 +532,7 @@ fn do_json_validation(
             Ok(obj) => obj,
             Err(e) => {
                 return Some(format!("{row_number_string}\t<RECORD>\t{e}"));
-            }
+            },
         }),
         schema_compiled,
     )
@@ -570,11 +570,17 @@ fn to_json_instance(
     // safety: we set NULL_TYPE in main() and it's never changed
     let null_type = NULL_TYPE.get().unwrap();
 
+    let mut key_string: String;
+    let mut value_string: String;
+    let mut field_def: &Value;
+    let mut field_type_def: &Value;
+    let mut json_type: u8;
+
     // iterate over each CSV field and convert to JSON type
     for (i, header) in headers.iter().enumerate() {
         // convert csv header to string. It's the key in the JSON object
-        let key_string = if let Ok(s) = from_utf8(header) {
-            s.to_string()
+        key_string = if let Ok(s) = from_utf8(header) {
+            s.to_owned()
         } else {
             let s = String::from_utf8_lossy(header);
             return fail!(format!("CSV header is not valid UTF-8: {s}"));
@@ -584,8 +590,8 @@ fn to_json_instance(
         let Some(value) = record.get(i) else {
             return fail!("CSV record is missing value for header '{key_string}' at index {i}");
         };
-        let value_string = if let Ok(s) = from_utf8(value) {
-            s.to_string()
+        value_string = if let Ok(s) = from_utf8(value) {
+            s.to_owned()
         } else {
             let s = String::from_utf8_lossy(value);
             return fail!(format!("CSV value is not valid UTF-8: {s}"));
@@ -598,12 +604,12 @@ fn to_json_instance(
         }
 
         // get json type from schema; defaults to STRING if not specified
-        let field_def: &Value = schema_properties.get(&key_string).unwrap_or(&Value::Null);
+        field_def = schema_properties.get(&key_string).unwrap_or(&Value::Null);
 
-        let field_type_def: &Value = field_def.get("type").unwrap_or(&Value::Null);
+        field_type_def = field_def.get("type").unwrap_or(&Value::Null);
 
         // we do json_type as a u8 so match will be a tad faster below
-        let json_type: u8 = match field_type_def {
+        json_type = match field_type_def {
             Value::String(s) => s.as_bytes()[0],
             Value::Array(vec) => {
                 // if can't find usable type info, defaults to "string"
@@ -623,11 +629,11 @@ fn to_json_instance(
                 }
 
                 return_val
-            }
+            },
             _ => {
                 // default to JSON String
                 b's'
-            }
+            },
         };
 
         // dbg!(i, &header_string, &value_string, &json_type);
@@ -637,13 +643,14 @@ fn to_json_instance(
             b's' => {
                 // string
                 json_object_map.insert(key_string, Value::String(value_string));
-            }
+            },
             b'n' => {
                 // number
-                if let Ok(float) = value_string.parse::<f64>() {
+                if let Ok(float) = fast_float::parse(&value_string) {
                     json_object_map.insert(
                         key_string,
-                        Value::Number(Number::from_f64(float).expect("not a valid f64 float")),
+                        // safety: we know it's a valid f64 from the fast_float::parse() above
+                        Value::Number(Number::from_f64(float).unwrap()),
                     );
                 } else {
                     return fail_format!(
@@ -651,7 +658,7 @@ fn to_json_instance(
                          type: number"
                     );
                 }
-            }
+            },
             b'i' => {
                 // integer
                 if let Ok(int) = value_string.parse::<i64>() {
@@ -662,7 +669,7 @@ fn to_json_instance(
                          type: integer"
                     );
                 }
-            }
+            },
             b'b' => {
                 // boolean
                 if let Ok(boolean) = value_string.parse::<bool>() {
@@ -673,10 +680,10 @@ fn to_json_instance(
                          type: boolean"
                     );
                 }
-            }
+            },
             _ => {
                 unreachable!("we should never get an unknown json type");
-            }
+            },
         }
     }
 
@@ -828,7 +835,7 @@ fn validate_json_instance(
             BasicOutput::Valid(_annotations) => {
                 // shouldn't happen
                 unreachable!("Unexpected error.");
-            }
+            },
         };
 
         Some(validation_errors)
@@ -943,14 +950,14 @@ fn load_json(uri: &str) -> Result<String, String> {
                 Ok(c) => c,
                 Err(e) => {
                     return fail_format!("Cannot build reqwest client: {e}.");
-                }
+                },
             };
 
             match client.get(url).send() {
                 Ok(response) => response.text().unwrap_or_default(),
                 Err(e) => return fail_format!("Cannot read JSON at url {url}: {e}."),
             }
-        }
+        },
         path => {
             let mut buffer = String::new();
             match File::open(path) {
@@ -958,11 +965,11 @@ fn load_json(uri: &str) -> Result<String, String> {
                     BufReader::new(p)
                         .read_to_string(&mut buffer)
                         .unwrap_or_default();
-                }
+                },
                 Err(e) => return fail_format!("Cannot read JSON file {path}: {e}."),
             }
             buffer
-        }
+        },
     };
 
     Ok(json_string)
