@@ -183,7 +183,7 @@ impl SelectorParser {
             match self.cur() {
                 None => {
                     return fail!("Unclosed quote, missing closing \".");
-                }
+                },
                 Some('"') => {
                     self.bump();
                     if self.cur() == Some('"') {
@@ -193,11 +193,11 @@ impl SelectorParser {
                         continue;
                     }
                     break;
-                }
+                },
                 Some(c) => {
                     name.push(c);
                     self.bump();
-                }
+                },
             }
         }
         Ok(name)
@@ -212,15 +212,15 @@ impl SelectorParser {
             match self.cur() {
                 None => {
                     return fail!("Unclosed index bracket, missing closing ].");
-                }
+                },
                 Some(']') => {
                     self.bump();
                     break;
-                }
+                },
                 Some(c) => {
                     idx.push(c);
                     self.bump();
-                }
+                },
             }
         }
         FromStr::from_str(&idx)
@@ -283,9 +283,9 @@ impl Selector {
                             inds.push(i);
                         }
                         inds
-                    }
+                    },
                 })
-            }
+            },
             Selector::Regex(ref re) => {
                 let inds: Vec<usize> = first_record
                     .iter()
@@ -299,7 +299,7 @@ impl Selector {
                     );
                 }
                 Ok(inds)
-            }
+            },
         }
     }
 }
@@ -326,7 +326,7 @@ impl OneSelector {
                     // Indices given by user are 1-offset. Convert them here!
                     Ok(i - 1)
                 }
-            }
+            },
             OneSelector::IndexedName(ref s, sidx) => {
                 if !use_names {
                     return fail_format!(
@@ -354,7 +354,7 @@ impl OneSelector {
                         num_found - 1
                     )
                 }
-            }
+            },
         }
     }
 }
@@ -394,6 +394,7 @@ impl Selection {
         // This is horrifying.
         #[allow(clippy::unnecessary_wraps)]
         #[allow(clippy::trivially_copy_pass_by_ref)]
+        #[allow(clippy::needless_pass_by_ref_mut)]
         fn get_field<'c>(row: &mut &'c csv::ByteRecord, idx: &usize) -> Option<&'c [u8]> {
             Some(&row[*idx])
         }
@@ -451,6 +452,7 @@ impl NormalSelection {
         }
         #[allow(clippy::option_option)]
         #[allow(clippy::unnecessary_wraps)]
+        #[allow(clippy::needless_pass_by_ref_mut)]
         fn get_field<T>(set: &mut &[bool], t: (usize, T)) -> Option<Option<T>> {
             let (i, v) = t;
             if i < set.len() && set[i] {
