@@ -320,6 +320,95 @@ END {
     wrk.assert_success(&mut cmd);
 }
 
+#[test]
+fn luau_aggregation_with_embedded_begin_end_using_file_no_jit() {
+    let wrk = Workdir::new("luau_embedded_begin_end");
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["letter", "Amount"],
+            svec!["a", "13"],
+            svec!["b", "24"],
+            svec!["c", "72"],
+            svec!["d", "7"],
+        ],
+    );
+
+    wrk.create_from_string(
+        "testbeginend.luau",
+        r#"
+BEGIN {
+    -- this is the BEGIN block, which is executed once at the beginning
+    -- where we typically initialize variables, setup functions
+    -- and load additional Lua libraries as required
+    running_total = 0;
+    grand_total = 0;
+    amount_array = {};
+    adjusted_array = {};
+
+    function margin(x: number, y: number ): number
+        return x * y;
+    end
+
+    function sum(numbers_array: table): number
+        local sum: number = 0;
+        for _, v in ipairs(numbers_array) do
+            sum = sum + v;
+        end
+        return sum;
+    end
+}!
+
+
+-- this is the MAIN script loop, which is executed for each row
+-- note how we use the _IDX special variable to get the row index
+amount_array[_IDX] = Amount;
+running_total = running_total + Amount;
+
+adjusted_array[_IDX] = Amount + margin(Amount, 0.25);
+
+-- running_total is the value we "map" to the "Running Total" column of each row
+return running_total;
+
+
+END {
+    -- and this is the END block, which is executed once at the end
+    grand_total = running_total;
+    min_amount = math.min(unpack(amount_array));
+    max_amount = math.max(unpack(amount_array));
+    adjusted_total = sum(adjusted_array);
+
+    -- note how we use the _ROWCOUNT special variable to get the number of rows
+    -- the value returned from the END script is sent to stderr
+    return (`Min/Max: {min_amount}/{max_amount} Grand total of {_ROWCOUNT} rows: {grand_total} adjusted: {adjusted_total}`);
+}!        
+"#,
+    );
+
+    let mut cmd = wrk.command("luau");
+    cmd.arg("map")
+        .arg("Running Total")
+        .arg("file:testbeginend.luau")
+        .arg("--no-jit")
+        .arg("data.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["letter", "Amount", "Running Total"],
+        svec!["a", "13", "13"],
+        svec!["b", "24", "37"],
+        svec!["c", "72", "109"],
+        svec!["d", "7", "116"],
+    ];
+    assert_eq!(got, expected);
+
+    let end = wrk.output_stderr(&mut cmd);
+    let expected_end = "Min/Max: 7/72 Grand total of 4 rows: 116 adjusted: 145\n".to_string();
+    assert_eq!(end, expected_end);
+
+    wrk.assert_success(&mut cmd);
+}
+
 #[test]
 fn luau_register_lookup_table() {
     let wrk = Workdir::new("luau_register_lookup_table");
@@ -617,6 +706,7 @@ END {
 }
 
 #[test]
+// #[ignore = "Temporarily skip this as Boston CityScore Summary is currently unavailable"]
 fn luau_register_lookup_table_ckan() {
     let wrk = Workdir::new("luau_register_lookup_ckan");
     wrk.create(
